<?php
include_once '../config/Database.php';
class Services
{
    private $dbConnect;
    public $clientTable = 'client';

    public function __construct()
    {
        $database = new Database();
        $this->dbConnect = $database->getConnection();
        if (!$this->dbConnect) {
            die("Failed to Connect to Database: " . $this->dbConnect);
        }
    }

    public function insertClient($clientData)
    {
        try {
            $values = [];
            $placeholders = [];

            foreach ($clientData as $key => $value) {
                $values[] = $value;
                $placeholders[] = "?";
            }
            $columns = implode(", ", array_keys($clientData));
            $placeholders = implode(", ", $placeholders);

            $clientQuery = "INSERT INTO " . $this->clientTable . " ($columns) VALUES ($placeholders)";

            $stmt = $this->dbConnect->prepare($clientQuery);
            if (!$stmt) {
                throw new Exception("Query preparation error: " . $this->dbConnect->error);
            }
            $types = str_repeat("s", count($clientData));
            $stmt->bind_param($types, ...$values);
            if ($stmt->execute()) {
                echo "Client inserted successfully.";
            } else {
                throw new Exception("Error inserting client: " . $stmt->error);
            }
            $stmt->close();
        } catch (Exception $e) {
            die("Error: " . $e->getMessage());
        }
    }

    public function viewClient()
    {
        try {
            $clientQuery = "SELECT * FROM " . $this->clientTable . " WHERE isdeleted=0";
            $result = $this->dbConnect->query($clientQuery);

            if (!$result) {
                throw new Exception("Error Fetching Clients: " . $this->dbConnect->error);
            }

            $clients = [];
            while ($row = $result->fetch_assoc()) {
                $clients[] = $row;
            }

            return $clients;
        } catch (Exception $e) {
            die("Error: " . $e->getMessage());
        }
    }

    public function updateClient($clientData)
    {
        try {
            $setStatements = [];
            $values = [];

            foreach ($clientData as $key => $value) {
                $setStatements[] = "$key = ?";
                $values[] = $value;
            }

            $values[] = $clientData['id'];

            $setStatements = implode(", ", $setStatements);

            $updateQuery = "UPDATE " . $this->clientTable . " SET $setStatements WHERE id = ?";

            $stmt = $this->dbConnect->prepare($updateQuery);
            if (!$stmt) {
                throw new Exception("Query preparation error: " . $this->dbConnect->error);
            }

            $types = str_repeat("s", count($values));
            $stmt->bind_param($types, ...$values);

            if ($stmt->execute()) {
                echo "Client updated successfully.";
            } else {
                throw new Exception("Error updating client: " . $stmt->error);
            }
            $stmt->close();
        } catch (Exception $e) {
            die("Error: " . $e->getMessage());
        }
    }

    public function destroyClient($clientId)
    {
        try {
            $deleteQuery = "UPDATE client SET isdeleted=1 WHERE id = ?";

            $stmt = $this->dbConnect->prepare($deleteQuery);
            if (!$stmt) {
                throw new Exception("Query preparation error: " . $this->dbConnect->error);
            }
            $stmt->bind_param("i", $clientId);

            if ($stmt->execute()) {
                $stmt->close();
                return ['success' => true];
            } else {
                throw new Exception("Error deleting user" . $stmt->error);
                return ['error' => true];
            }
        } catch (Exception $e) {
            return ["error" => true, "message" => "Error: " . $e->getMessage()];
        }
    }
}
