<?php
// Includes Global Site URL;
include("../includes/site-info.php");
require_once("../api/config/Database.php");

$database = new Database();

$conn = $database->getConnection();


if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    if (isset($_POST['delete_contract']) && isset($_POST['contract_id'])) {

        $contractId = $_POST['contract_id'];

        $deleteQuery = "UPDATE contracts SET isdeleted = 1 WHERE id = ?";
        $stmt = $conn->prepare($deleteQuery);

        if ($stmt) {
            $stmt->bind_param("i", $contractId);
            if ($stmt->execute()) {
                echo json_encode(["success" => true]);
            } else {
                echo json_encode(["success" => false, "error" => "Error deleting record: " . $stmt->error]);
            }
            $stmt->close();
        } else {
            echo json_encode(["success" => false, "error" => "Error preparing statement: " . $conn->error]);
        }
    } else {
        echo json_encode(["success" => false, "error" => "Invalid parameters for delete operation"]);
    }
    exit;
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <title>View Contracts</title>

    <!-- Compatibility -->
    <?php include("../includes/compatibility.php"); ?>
    <!-- Compatibility -->


    <!-- styles start -->
    <?php include("../includes/header-styles.php"); ?>
    <!-- styles end -->

</head>

<body data-layout="horizontal">

    <!-- Begin page -->
    <div id="wrapper">

        <!-- Navigation Bar-->
        <?php include("../includes/header.php"); ?>
        <!-- End Navigation Bar-->

        <!-- ============================================================== -->
        <!-- Start Page Content here -->
        <!-- ============================================================== -->

        <div class="content-page">
            <div class="content">
                <!-- Start container-fluid -->
                <div class="container-fluid">

                    <!-- PAGE HEADING -->
                    <div class="page-heading-wrapper">
                        <h1 class="text-center page-heading mb-5">View contracts</h1>
                    </div>
                    <!-- PAGE HEADING -->

                    <div class="form-main-layout pb-5">

                        <!-- start  -->
                        <div class="row">
                            <div class="col-12">
                                <div>
                                    <h4 class="header-title mb-4 ">View contract Details</h4>
                                </div>
                            </div>
                        </div>
                        <!-- end row -->



                        <div class="mt-5">
                            <table id="basic_table" class="table table-bordered table-bordered  " style="border-collapse: collapse; border-spacing: 0; width: 100%;">

                                <thead class="thead-dark">
                                    <!-- COLUMN NAMES -->
                                    <tr>
                                        <th>Client Name</th>
                                        <th>Next Due Date</th>
                                        <th>Contract Renewal Date</th>
                                        <th>Contract Amount</th>
                                        <th>Contract Returned</th>
                                        <th>Additional Comments</th>
                                        <th>Functions</th>
                                    </tr>
                                </thead>

                                <tbody>
                                    <!-- BODY -->
                                    <?php
                                    $sql = "SELECT c.id, c.client_id, c.next_due_date, c.contract_amount, c.contract_renewal_date, c.contract_returned, c.additional_comment, cl.company_name 
                                   FROM contracts c
                                   JOIN client cl ON c.client_id = cl.id
                                   WHERE c.isdeleted=0";

                                    $result = $conn->query($sql);

                                    if ($result->num_rows > 0) {
                                        // Output data of each row
                                        while ($row = $result->fetch_assoc()) {
                                    ?>
                                            <tr>
                                                <td><strong><?php echo $row['company_name']; ?></strong></td>
                                                <td><?php echo date('jS M, Y', strtotime($row['next_due_date'])); ?></td>
                                                <td><?php echo date('jS M, Y', strtotime($row['contract_renewal_date'])); ?></td>
                                                <td><?php echo '$' . number_format($row['contract_amount'], 2); ?></td>
                                                <td><?php echo ($row['contract_returned'] == 1) ? 'Yes' : 'No'; ?></td>
                                                <td><?php echo $row['additional_comment']; ?></td>
                                                <td class="function_button_wrap">

                                                    <a class="btn btn-primary flex-1" href="contract/edit-contract.php?id=<?php echo $row['id']; ?>&company_name=<?php echo $row['company_name']; ?>&next_due_date=<?php echo $row['next_due_date']; ?>&contract_renewal_date=<?php echo $row['contract_renewal_date']; ?>&contract_amount=<?php echo $row['contract_amount']; ?>&contract_returned=<?php echo $row['contract_returned']; ?>&additional_comment=<?php echo $row['additional_comment']; ?>">Edit</a>
                                                    <?php
                                                    echo '<button class="btn btn-warning flex-1 view-contract" data-toggle="modal" data-target="#viewContractModal" onclick="openViewClientModal(' . htmlspecialchars(json_encode($row), ENT_QUOTES, 'UTF-8') . ')" type="button">View</button>';
                                                    ?>
                                                    <button type="button" class="btn btn-danger flex-1 waves-effect waves-light btn-sm sa-warning" data-contract-id="<?php echo $row['id']; ?>">Delete</button>
                                                </td>
                                            </tr>
                                    <?php
                                        }
                                    } else {
                                        echo "0 results";
                                    }
                                    ?>


                                </tbody>
                            </table>
                        </div>


                    </div>
                    <!-- end container-fluid -->

                    <!-- Footer Start -->
                    <?php include("../includes/footer.php"); ?>
                    <!-- end Footer -->
                </div>
                <!-- end content -->
            </div>
            <!-- END content-page -->
        </div>
        <!-- END wrapper -->

        <!-- Right Sidebar -->
        <?php //include("../includes/right-bar.php"); 
        ?>
        <!-- /Right-bar -->


        <?php include("../includes/view-page-footer-scripts.php"); ?>


        <!-- Modal -->
        <div class="modal fade" id="viewContractModal" tabindex="-1" role="dialog" aria-labelledby="viewContractModal" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered modal-xl" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title page-heading w-50 mr-0 ml-0 d-block" id="exampleModalLongTitle">Viewing contract: <span id="contract-name"></span></h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body py-4">
                        <div class="form-main-layout">


                            <form class="form-horizontal">
                                <div class="form-group row">
                                    <label for="client_name" class="col-md-2 control-label">Client Name</label>
                                    <div class="col-md-10">
                                        <input readonly type="text" value="lunar Innovations" class="form-control" id="client_name">
                                    </div>
                                </div>
                                <div class="form-group form-group row">
                                    <label class="col-md-2 col-form-label" for="contract_next_due_date">Next Due Date</label>
                                    <div class="col-md-10">
                                        <div class="input-group">
                                            <input readonly type="text" class="form-control" value="24th Jan, 2023" id="contract_next_due_date">
                                        </div>
                                    </div>
                                </div>

                                <div class="form-group row">
                                    <label for="contract_amount" class="col-md-2 control-label">Contract Amount</label>
                                    <div class="col-md-10">
                                        <input readonly type="text" class="form-control" value="$1,000" id="contract_amount">
                                    </div>
                                </div>
                                <div class="form-group form-group row">
                                    <label class="col-md-2 col-form-label" for="contract_renewal_date">Contract Renewal Date</label>
                                    <div class="col-md-10">
                                        <div class="input-group">
                                            <input readonly type="text" class="form-control" value="24th Jan, 2023" id="contract_renewal_date">
                                        </div>
                                    </div>
                                </div>
                                <div class="form-group row">
                                    <label class="col-md-2 col-form-label" for="contract_returned">Contract Returned</label>
                                    <div class="col-md-10">
                                        <input type="text" value="NO" readonly class="form-control" id="contract_returned">
                                    </div>
                                </div>

                                <div class="form-group row">
                                    <label class="col-md-2 col-form-label" for="contract_additional_comments">Additional Comments</label>
                                    <div class="col-md-10">
                                        <textarea readonly class="form-control" rows="5" id="contract_additional_comments">Some Details Here.</textarea>
                                    </div>
                                </div>

                            </form>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" data-dismiss="modal" class="btn btn-danger btn-lg">Close</button>

                        <a type="button" id="editButton" href=" #" class="text-white btn btn-primary btn-lg">Edit</a>
                    </div>
                </div>

            </div>
        </div>
    </div>

    <script>
        function openViewClientModal(clientData) {
            try {
                console.log(clientData);
                $('#client_name').val(clientData.company_name);
                $('#contract_next_due_date').val(clientData.next_due_date);
                $('#contract_amount').val(clientData.contract_amount);
                $('#contract_renewal_date').val(clientData.contract_renewal_date);
                $('#contract_returned').val(clientData.contract_returned);
                $('#contract_additional_comments').val(clientData.additional_comment);


                var editUrl = 'equipment/edit-equipment.php' +
                    '?id=' + encodeURIComponent(clientData.id) +
                    '&next_due_date=' + encodeURIComponent(clientData.next_due_date) +
                    '&contract_amount=' + encodeURIComponent(clientData.contract_amount) +
                    '&contract_renewal_date=' + encodeURIComponent(clientData.contract_renewal_date) +
                    '&contract_returned=' + encodeURIComponent(clientData.contract_returned) +
                    '&additional_comment=' + encodeURIComponent(clientData.additional_comment);

                $('#editButton').attr('href', editUrl);

                $('#viewClientModal').modal('show');
            } catch (error) {
                console.error('Error parsing JSON:', error);
            }
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.all.min.js"></script>


    <script>
        $(document).ready(function() {
            $(".sa-warning").click(function() {
                var contractId = $(this).data('contract-id');

                Swal.fire({
                    title: "Are you sure?",
                    text: "You won't be able to revert this!",
                    type: "warning",
                    showCancelButton: true,
                    confirmButtonColor: "#458bc4",
                    cancelButtonColor: "#6c757d",
                    confirmButtonText: "Yes, delete it!"
                }).then(function(result) {
                    if (result.value) {
                        $.ajax({
                            type: "POST",
                            url: window.location.href,
                            data: {
                                delete_contract: true,
                                contract_id: contractId
                            },
                            dataType: "json",
                            success: function(response) {
                                if (response.success) {
                                    Swal.fire("Deleted!", "Your file has been deleted.", "success");
                                } else {
                                    Swal.fire("Error", "Failed to delete file. " + response.error, "error");
                                }
                            },
                            error: function() {
                                Swal.fire("Error", "Failed to communicate with the server.", "error");
                            }
                        });
                    }
                });
            });
        });
    </script>



</body>

</html>